#
# spec file for package NetworkManager
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           NetworkManager
Url:            http://www.gnome.org/projects/NetworkManager/
Version:        0.8.2
Release:        15.28.1
License:        GPLv2+
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  dbus-1-devel dbus-1-glib-devel gtk-doc intltool iptables libgcrypt-devel libgudev-1_0-devel libiw-devel libnl-devel libtool libuuid-devel mozilla-nss-devel polkit-devel ppp-devel translation-update-upstream wireless-tools
Group:          Productivity/Networking/System
Summary:        Network Link Manager and User Applications
Source0:        NetworkManager-%{version}.tar.bz2
Source1:        nfs
Source2:        nm-system-settings.conf
# bnc#476502, add a general frontend dbus configuration for 
# nm-applet, cnetworkmanager, knetworkmanager, bili@novell.com
Source3:        NetworkManager-frontend.conf
Source99:       NetworkManager-rpmlintrc
# PATCH-FIX-UPSTREAM nm-64bit-timestamp.diff -- Taken from git
Patch0:         nm-64bit-timestamp.diff
# PATCH-FIX-UPSTREAM nm-nis-domain.diff -- Taken from git
Patch1:         nm-nis-domain.diff
# PATCH-FIX_USPTREAM nm-crash-lack-ipv4.patch jeffm@suse.de -- Taken from git
Patch2:         nm-crash-lack-ipv4.patch
# PATCH-FIX-UPSTREAM nm-ignore-temp-files.patch bgo#602868 bnc#668183 bjorn.lie@gmail.com -- Silence on warning for non-existing temp files. Taken from git 		
Patch3:         nm-ignore-temp-files.patch
# PATCH-FIX-UPSTREAM nm-stop-touching-hosts.patch bnc#667265 binli@opensuse.org -- Stop touching /etc/hosts. Taken from git 		
Patch4:         nm-stop-touching-hosts.patch
# PATCH-FIX-UPSTREAM nm-destory-crash.patch bnc#673627 binli@opensuse.org -- Fix crash when NM exit.
Patch5:         nm-destory-crash.patch
# PATCH-FIX-UPSTREAM nm-suppress-user-proxy-error-msg.patch bnc#687001 binli@opensuse.org -- Suppress the user_proxy_init() errors.
Patch6:         nm-suppress-user-proxy-error-msg.patch
# PATCH-FIX-UPSTREAM nm-dismiss-keyfile-spam.patch bnc#681072 binli@opensuse.org -- Dismiss the keyfile's spam log.
Patch7:         nm-dismiss-keyfile-spam.patch
# PATCH-FIX-UPSTREAM NetworkManager-dhcp-hostname-true.patch bnc#557720 binli@opensuse.org -- Set the dhcp-hostname to true.
Patch8:         %{name}-dhcp-hostname-true.patch
# PATCH-FIX-UPSTREAM nm-settings-subject-match.patch bnc#574266 glin@suse.com -- Add subject to nm-settings-80211x
Patch9:         nm-settings-subject-match.patch
# PATCH-FIX-UPSTREAM nm-probe-ca-cert.patch bnc#574266 glin@suse.com -- Probe the RADIUS server certificate
Patch10:        nm-probe-ca-cert.patch
# PATCH-FIX-UPSTREAM nm-check-for-shared-wifi-authorization.patch bnc#702016 glin@suse.com -- Check whether the shared wifi is authorized or not
Patch11:        nm-check-for-shared-wifi-authorization.patch
Requires:       %{name}-glib = %{version}
Requires:       dhcp-client
Requires:       iproute2
Requires:       iputils
Requires:       libnl >= 1.1
Requires:       mozilla-nss
Requires:       ppp
Requires:       sysconfig >= 0.71.1
Requires:       wpa_supplicant >= 0.6.4
Provides:       dhcdbd = 1.14
Obsoletes:      dhcdbd < 1.14
Recommends:     dnsmasq
Recommends:     iptables
Recommends:     NetworkManager-client
Recommends:     org.freedesktop.ModemManager
Recommends:     %{name}-lang

%description
NetworkManager attempts to keep an active network connection available
at all times.  The point of NetworkManager is to make networking
configuration and setup as painless and automatic as possible.	If
using DHCP, NetworkManager is intended to replace default routes,
obtain IP addresses from a DHCP server, and change name servers
whenever it sees fit.

%package devel
License:        GPLv2+
Summary:        Libraries and headers for adding NetworkManager support to applications
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       %{name}-glib = %{version}
Requires:       dbus-1 >= %( echo `rpm -q --queryformat '%{VERSION}' dbus-1`)
Requires:       dbus-1-glib >= %( echo `rpm -q --queryformat '%{VERSION}' dbus-1-glib`)
Requires:       dbus-1-devel
Requires:       glib2-devel
Requires:       dbus-1-glib-devel
Requires:       libgcrypt-devel
Requires:       libgpg-error-devel

%description devel
This package contains various headers accessing some NetworkManager
functionality from applications.

%package glib
License:        GPLv2+
Summary:        Libraries for adding NetworkManager support to applications that use glib
Group:          Development/Libraries/GNOME

%description glib
This package contains the libraries that make it easier to use some
Network Manager functionality from applications that use glib.

%package doc
License:        GPLv2+
Summary:        Network Link Manager and User Applications
Group:          Productivity/Networking/System

%description doc
NetworkManager attempts to keep an active network connection available
at all times.  The point of NetworkManager is to make networking
configuration and setup as painless and automatic as possible.	If
using DHCP, NetworkManager is intended to replace default routes,
obtain IP addresses from a DHCP server, and change name servers
whenever it sees fit.

%lang_package
%prep
%setup -n %{name}-%{version} -q
%patch0
%patch1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1
translation-update-upstream

%build
autoreconf	# needed for Patch3 to properly expand.
pppddir=`ls -1d /usr/%_lib/pppd/2*`
test -n "$pppddir" || exit 1
export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
%configure\
    --libexecdir=%{_prefix}/lib/NetworkManager\
    --disable-static\
    --with-crypto=nss \
    --with-distro=suse\
    --with-docs\
    --enable-more-warnings=no \
    --with-pppd-plugin-dir=$pppddir \
    --with-dhclient=/sbin/dhclient
%__make %{?_smp_flags}

%install
%makeinstall
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/VPN
./libtool --mode=install install -m 755 test/nm-online $RPM_BUILD_ROOT%{_bindir}/
mkdir -p $RPM_BUILD_ROOT/var/log/
touch $RPM_BUILD_ROOT/var/log/NetworkManager
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/system-connections
install -m 0755 %{SOURCE1} $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/dispatcher.d/
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/NetworkManager/
install -m 0644 %{SOURCE3} $RPM_BUILD_ROOT%{_sysconfdir}/dbus-1/system.d/

%clean
rm -rf "$RPM_BUILD_ROOT"

%post
/sbin/ldconfig

%postun -p /sbin/ldconfig

%post glib -p /sbin/ldconfig

%postun glib -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc COPYING ChangeLog NEWS AUTHORS README CONTRIBUTING TODO
%{_bindir}/nm-tool
%{_bindir}/nm-online
%{_bindir}/nmcli
%{_mandir}/man5/NetworkManager.conf.5*
%{_mandir}/man5/nm-system-settings.conf.5*
%dir %{_prefix}/%_lib/pppd/2.4.5
%{_prefix}/%_lib/pppd/2.4.5/nm-pppd-plugin.*
%{_datadir}/NetworkManager
%{_datadir}/dbus-1/system-services/org.freedesktop.nm_dispatcher.service
%{_datadir}/polkit-1/actions/org.freedesktop.NetworkManager.policy
%{_datadir}/polkit-1/actions/org.freedesktop.network-manager-settings.system.policy
 %attr(0700,root,root) %{_localstatedir}/run/NetworkManager
%doc %{_mandir}/man1/*.*
%doc %{_mandir}/man8/*.*
# On 64-bit biarch systems, the libraries go to /usr/lib64/NetworkManager,
# and libexec-y things remain in /usr/lib/NetworkManager.
# Whereas on single-arch or 32-bit biarch, everything goes into
# /usr/lib/NetworkManager.
%ifarch x86_64 ppc64 s390x sparc64
%{_libdir}/NetworkManager
%endif
%{_prefix}/lib/NetworkManager
%{_sbindir}/*
%{_sysconfdir}/dbus-1/system.d/NetworkManager.conf
%{_sysconfdir}/dbus-1/system.d/nm-dhcp-client.conf
%{_sysconfdir}/dbus-1/system.d/nm-dispatcher.conf
%{_sysconfdir}/dbus-1/system.d/nm-avahi-autoipd.conf
%dir %{_sysconfdir}/NetworkManager
%dir %{_sysconfdir}/NetworkManager/dispatcher.d
%dir %{_sysconfdir}/NetworkManager/system-connections
%{_sysconfdir}/NetworkManager/nm-system-settings.conf
%{_sysconfdir}/dbus-1/system.d/NetworkManager-frontend.conf
%attr(0755,root,root) %{_sysconfdir}/NetworkManager/dispatcher.d/nfs
%dir /lib/udev
%dir /lib/udev/rules.d
/lib/udev/rules.d/77-nm-olpc-mesh.rules
%ghost %config(noreplace) /var/log/NetworkManager

%files devel
%defattr(-,root,root)
%{_includedir}/NetworkManager
%{_includedir}/libnm-glib
%{_libdir}/libnm-util.so
%{_libdir}/libnm-glib.so
%{_libdir}/libnm-glib-vpn.so
%{_libdir}/pkgconfig/NetworkManager.pc
%{_libdir}/pkgconfig/libnm-util.pc
%{_libdir}/pkgconfig/libnm-glib.pc
%{_libdir}/pkgconfig/libnm-glib-vpn.pc

%files glib
%defattr(-,root,root)
%{_libdir}/libnm-util.so.*
%{_libdir}/libnm-glib.so.*
%{_libdir}/libnm-glib-vpn.so.*

%files doc
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc/html/libnm-glib
%{_datadir}/gtk-doc/html/libnm-glib/*
%dir %{_datadir}/gtk-doc/html/libnm-util
%{_datadir}/gtk-doc/html/libnm-util/*

%files lang -f %{name}.lang

%changelog
* Thu Nov  3 2011 glin@suse.com
- Add nm-check-for-shared-wifi-authorization.patch to check whether
  the shared wifi connection is authorized or not. (bnc#702016)
* Fri Oct 21 2011 glin@suse.com
- Add nm-settings-subject-match.patch and nm-probe-ca-cert.patch
  to probe the RADIUS server certificate and set the subject
  (bnc#574266)
* Fri May 27 2011 bili@novell.com
- Add the NetworkManager-dhcp-hostname-true.patch, which send the
  dhcp-hostname to server by default(bnc#557720,swampid#41130).
* Wed Apr 27 2011 binli@opensuse.org
- Add nm-dismiss-keyfile-spam.patch to dismiss spam log(bnc#681072).
- Add nm-suppress-user-proxy-error-msg.patch, suppress
  the user_proxy_init() errors(bnc#687001,swampid#40478).
* Mon Feb 21 2011 binli@opensuse.org
- Add nm-destory-crash.patch, fix crash when NM exit(bnc#673627).
* Tue Feb 15 2011 binli@opensuse.org
- Add the nm-stop-touching-hosts.patch to stop touching /etc/hosts.
  (bnc#667265)
* Wed Feb  2 2011 bjorn.lie@gmail.com
- Added autoreconf since nm-ignore-temp-files.patch needs more
  than touching Makefile.in.
* Sun Jan 30 2011 bjorn.lie@gmail.com 
- Add nm-ignore-temp-files.patch: stop NM from filling dmesg and
  logs by ignoring temporary files (bgo#602868) (bnc#668183)
  Original upstream patch has been extended to also touch
  Makefile.in in order to avoid having to re-bootstrap.
* Fri Jan 14 2011 jeffm@suse.de
- Add nm-crash-lack-ipv4.patch to fix a crash during exit: lack of
  an IPv4 setting indicates DHCP (bnc#664640).
* Tue Dec 14 2010 vuntz@opensuse.org
- Stop removing sr@Latn translation: it was added by
  translation-update-upstream, and the script got fixed now.
* Wed Nov 24 2010 tittiatcoke@gmail.com
- Add patch to fix NM crash (bnc#655685)
* Tue Nov 23 2010 wstephenson@novell.com
- Add patch to fix NM crash with ethernet (bnc#655505)
* Wed Nov 10 2010 coolo@novell.com
- Remove sr@Latn as it's a duplicate of sr@latin and no valid
  locale.
* Sat Nov  6 2010 dimstar@opensuse.org
- Update to version 0.8.2:
  + Native local caching nameserver support using dnsmasq
  + Automatically detect addition and removal of new VPN plugins
  + Support for handling suspend/resume signals from UPower
  + Ensure users are allowed to enable/disable WiFi and networking
  + Ensure WiFi enable state is preserved across reboot and suspend
  + Better handling of /etc/hosts and preservation of custom
    hostnames
  + Support for the systemd session management service
  + Better handling of 'keyfile' system connection errors
  + Support for S390 network devices
  + and much more...
- Split out lang package.
- Pass --with-docs to configure.
* Mon Aug  9 2010 vuntz@opensuse.org
- Change --with-dhcp-client configure option to --with-dhclient.
- Re-enable parallel build.
* Mon Jul 26 2010 dimstar@opensuse.org
- Update to version 0.8.1:
  + Bluetooth Dial-Up Networking
  + nmcli: a command-line interface for controlling NetworkManager
  + Mobile Broadband Status: signal strength, roaming, and access
    technology display
  + Enhanced IPv6 support: including DHCPv6 and tons of fixes
  + Logging and Debugging: make NM as quiet or verbose as you like
- Drop NetworkManager-netconfig-exit-quick.patch, upstreamed.
- Drop NetworkManager-NIS.patch, no longer required.
* Fri Jul 23 2010 bili@novell.com
- nfs script should not use nfs restart(bnc#559021).
* Fri Jul  9 2010 jengelh@medozas.de
- Add SPARC targets to %%files list
- Reword comment about locations of files (since sparcv9 is neither
  single-arch nor a 64-bit environment)
* Wed Jun 30 2010 bili@novell.com
- Update NetworkManager-NIS.patch, init the variable(bnc#618599).
* Tue Jun 29 2010 bili@novell.com
- Add NetworkManager-netconfig-exit-quick.patch, fix wrong return
  value when updating the DNS with netconfig(bnc#595708, bnc#544195,
  bnc#537907, bnc#596163).
* Thu Jun 24 2010 bili@novell.com
- Add NetworkManager-NIS.patch, support NIS domain and servers
  (bnc#608677).
* Tue Jun 15 2010 dimstar@opensuse.org
- Minor spec-cleanup.
* Wed Jun  9 2010 cristian.rodriguez@opensuse.org
- fix NetworkManager dependencies
  * ModemManager and dnsmasq should be recommended, not required
  * should Require iproute2,iputils and ppp
  * Should Recommend iptables
* Wed May 19 2010 lnussel@suse.de
- remove not needed build time dependency on dhcp-client
* Fri Apr 23 2010 bili@novell.com
- Add a general dbus conf file for nm-applet, cnetworkmanager and
  NetworkManager-kde4(bnc#476502).
* Mon Feb 22 2010 dimstar@opensuse.org
- Update to version 0.8:
  + introspection: fix inclusion of Dhcp6Config XML
  + crypto: de-init NSS after calling PR_GetError()
  + ifcfg-rh: read and write DHCPv6 connections
  + policy: fall back to original hostname before trying reverse
    DNS
  + bluetooth: finish DUN implementation
  + introspection: sync device state reason code with
    NetworkManager.h
  + policy: be more selective when adding hostname to /etc/hosts
  + gsm: handle PIN requests during modem enable too
  + system-settings: register setting errors so D-Bus errors are
    meaningful
  + Updated translations.
* Fri Feb 12 2010 vuntz@opensuse.org
- Add NetworkManager-rpmlintrc to list of sources.
- Fix self-obsoletion of dhcdbd.
* Sat Jan 30 2010 captain.magnus@opensuse.org
- Update to version 0.7.999:
  + ifcfg-rh: formatting fix
  + ifcfg-rh: handle missing PREFIX by generating one
  + ifcfg-rh: ensure IPv6 addresses are cleared when none get
    written out
  + ifcfg-rh: add IPv6 addressing and routes support (rh #523288)
  + backends: add backend for Pardus
  + libnm-util: fix NMDeviceBt hardware address property
  + core: ensure failed /etc/hosts update writes out
    well-formatted file (lp#471498)
  + olpc-mesh: fix companion path and active channel property
    types
  + netlink: work around kernel cache refill problems
  + keyfile: add IPv6 support (bgo #593814)
  + libnm-util: add IPv6 comparison functions
  + Translation updates
- Remove 0006-NIS-patch.patch, 0007-Fix-etc-hosts-updating.patch,
  nm-hal-tree-changes.patch and
  0009-Implement-sending-system-hostname-with-DHCP-client.patch.
  These patches were not applied
* Thu Jan 21 2010 tambet@novell.com
- Upgrade to the latest upstream 0.8 branch:
  + Add support for Bluetooth DUN devices.
  + Add support to manually deactivate active devices.
  + Much improved killswitch handling.
  + The state (networking, wireless, ...) is now remembered after
    reboots.
  + The system settings daemon is removed and the main daemon has
    support for distribution specific plugins now.
  + The keyfile plugin supports a lot more data formats now (human
    readable IP addresses, passwords without hashing etc). Add
    back the support for certificate file paths.
  + Add back support for multiple CA certificate per (.PEM) file.
  + HAL usage is replaced with gudev.
  + IPv6 support.
  + Documentation updates.
  + Lots of bug fixes.
* Mon Oct  5 2009 tambet@novell.com
- Never fall back to manually updating resolv.conf, even if
  netconfig fails (bnc #537907, #544195).
* Mon Sep 14 2009 tambet@novell.com
- Fix a segfault introduced by the updated ModemManager patch
  (bnc #538180).
* Wed Aug 26 2009 tambet@novell.com
- HAL added 'ssb' (Silicon Sonics Backplane, used internally on
  most Broadcom ethernet and wifi chipsets) in 0.5.13, which
  changed the device list layout and made NM unable to get the
  driver for the wifi device. Fix that (bnc #526105).
* Tue Aug 25 2009 tambet@novell.com
- Fix issues with root being at_console (bnc #530430).
* Thu Aug 20 2009 aj@suse.de
- Require libiw-devel for building instead of wireless-tools.
* Tue Aug 11 2009 tittiatcoke@gmail.com
- Update to latest 0.7.1 upstream
  + Handle ZTE (Onda) device port types
  + Wait 20 seconds (instead of 15) for PPP connections to come up
  + Block until netconfig exits
  + Allow 63 byte long PSK
  + Fix dbus reconnection
  + Handle unsolicited supplicant scans
  + Other fixes
* Tue Jul 21 2009 aj@suse.de
- Add 0013-iptables-path.patch to correct path for iptables, it lives
  in /usr/sbin.
* Tue Jul 14 2009 tittiatcoke@gmail.com
- Added Build dependency for libuuid
* Wed May 27 2009 tambet@novell.com
- Update to 0.7.1:
  + Plays better with stupid wifi and ethernet drivers.
  + Support for rfc3442 classless static routes.
  + The default "Auto eth0" connection is now read/write.
  + Compatibility fixes for 802.1x PEAP authentication and 3G/PPP
    connections.
  + Reduced wakeups for power saving awesomeness.
  + Ability to deny specific devices the default route.
  + More correct display of wifi signal strength.
  + Custom IPv4 settings for mobile broadband connections.
  + More informative display of network device state.
  + Lots of bugs fixed.
* Mon Feb 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Wed Feb 11 2009 vuntz@novell.com
- Remove non-upstream translations: they'll get out-of-date.
* Sat Jan 31 2009 vuntz@novell.com
- Use sr@latin instead of sr@Latn.
* Mon Jan 12 2009 mauro@suse.de 
- Translations update.
* Thu Jan  8 2009 mauro@suse.de
- Translations update.
* Sat Dec  6 2008 mauro@suse.de
- Translations update.
* Thu Dec  4 2008 tambet@novell.com
- Fix merging the default route (bnc #450553).
* Tue Dec  2 2008 tambet@novell.com
- Rebase from the official NetworkManager 0.7.0 release:
  + Documentation fixes and updates.
  + Updated translations: de, fi, or, sv.
- Fix the /etc/hosts file updating (bnc #433365).
- Fix NIS information updating (bnc #437320).
- Really fix the location of dhclient leases file (bnc #446611).
* Fri Nov 21 2008 tambet@novell.com
- Add support to use distro wide CA certificates from
  /ets/ssl/certs (bnc #436192).
- Unmount NFS shares when network is deactivated (bnc #341647).
- Recomment NetworkManager-client (bnc #445643).
- Fix the location of dhclient leases file (bnc #446611).
- Add support for having certificate filenames in system
  connections.
- Add API reference documentation for libnm-util.
- Handle gateways in different subnets.
- Add support for PKCS#12 certificates (bgo #558982).
- Update translations: es, pl, se
* Fri Nov 14 2008 tambet@novell.com
- Use system CA certificates in case the CA isn't set on connection.
* Mon Nov 10 2008 tambet@suse.de
- Fix the bug where the keyfile system settings plugin would
  return empty strings for passwords when they're not set.
* Fri Nov  7 2008 tambet@suse.de
- Add support for passing through PKCS#11 certificates.
- Monitor /etc/HOSTNAME and set hostname accordingly (bnc #)440809.
* Mon Nov  3 2008 tambet@suse.de
- Break the public API to hide the internal data structures in
  hope to achieve maintainable public API from now on.
* Fri Oct 24 2008 tambet@suse.de
- Fix the problem where NetworkManager thinks it can't start ModemManager.
- Always add really important stuff to the command line to ensure
  that NM overrides /etc/ppp/options (bgo #556781).
- Fix segfaults on shutdown.
- Correctly determine encryption capabilities.
- Add support for VPN subnet gateways (bgo #549196).
- Rework default route handling to consolidate decisions in the policy,
  and to take active VPN connections into account when changing the default
  route (bgo #545912).
- Updated translations: be, es, nb, pt_BR, sv.
* Mon Oct 20 2008 tambet@suse.de
- Implement merging connections from /etc/sysconfig/network in
  nm-opensuse-merge (part of bnc #433084).
* Fri Oct 10 2008 tambet@suse.de
- Update to the latest upstream:
  + Add a 'hostname' dispatcher action triggered on hostname changes
    (bgo #552983).
  + Fix a memory corruption in setting routes.
  + Fix system connections saving after modifications.
  + Fix a system settings crash on removal of ethernet devices.
  + Make PPP username & password handling more robust.
  + Clear secrets on invalid connections.
  + Fix setting value comparison issues.
  + Set route priorities correctly for multiple active devices in the same
    subnet.
  + Handle ipw3945 suspend/resume by retrying the GIWRANGE request a few
    times when it returns EAGAIN (rh #362421).
  + Update translations: es, et, fi, lv, nb, sv.
- NetworkManager always sets full hostname instead of short one (bnc #433179).
- NetworkManager does not require more exact libnl version (bnc #421735).
- NetworkManager: ethtool_cmd now has a speed_hi field to support devices
  faster than 65535 Mb (bnc #431512).
- Fix a bug where during shutdown, NetworkManager messages pollute the
  console (bnc #391747).
- Fix typoes in CDMA device which made them appear as GSM devices
  (bgo #430502).
* Fri Sep 26 2008 tambet@suse.de
- Update to the latest from upstream:
  + Add support for static and dynamic hostnames.
  + Correctly clean wpa_supplicant state on shutdown (bnc #404883).
  + Fix a crash when a device is removed (bgo #549401).
  + Fix (bgo #551361).
  + Updated translations: it br sv lt fi hu fr.
* Thu Sep 25 2008 ro@suse.de
- use autoreconf -f -i for new libtool
* Fri Sep 19 2008 tambet@suse.de
- Update NIS information from a dispatcher script.
- Make it build on 11.0 as well.
- Update to the latest upstream:
  + Default to "all ciphers" for wireless security setting.
  + Fix a problem where unamanaged devices could cause recursive connection reloads.
  + Fix a typo causing crashes in keyfile plugin.
  + Updated translations: cs, fi, fr, nl.
* Mon Sep 15 2008 ro@suse.de
- added directory to filelist
* Sun Sep 14 2008 aj@suse.de
- Fix directory ownership.
- Remove unneeded build require on ppp.
* Fri Sep 12 2008 tambet@suse.de
- Bring up to date with SVN.
- Add patches to remove the built in modem code and use ModemManager
  instead.
- Create a -doc package now that NetworkManager has API reference
  documentation.
* Fri Aug  1 2008 tambet@suse.de
- Bring up to date with SVN again.
* Mon Jun 30 2008 tambet@suse.de
- Bring up to date with SVN again.
* Mon Jun 30 2008 tambet@suse.de
  SWAMP-ID: 18426
- Don't assume DHCP server always returns a gateway (bnc #392598).
- Missing default route in case the gateways is in another subnet (bnc #266215).
- Cannot enter PIN code with some modems (bnc #394731).
- Changes in yast not picked up until reboot (bnc #378802).
- Make sure pppd is shut down, even if it's blockin on reads (bnc #394598).
- Fix a lifetime issue with VPN services (bnc #381769).
* Wed Jun  4 2008 tambet@suse.de
- Fix a bug where NetworkManager does not work at all in case there are
  devices marked with NM_CONTROLLED="no" (bnc #390404).
* Sat May 24 2008 aj@suse.de
- Disable parallel build for now as it let to build failures.
* Fri May 23 2008 tambet@suse.de
- Fix the configuration file path sent to dhclient (bnc #390770).
- Move crypto handling to NetworkManager (from NetworkManager-gnome), implement
  WPA-EAP configuration reading for sysconfig.
- Make the system settings service exit when the bus goes away. (brc #444976).
- If the default gateway is in another subnet, first add route to it, then the
  default route (bnc #266215).
- Optimize waking up after suspend, don't remove all the devices and then add
  everything back. Just syncronize with HAL.
- Close serial devices when not active or activating (bnc #392604 and
  bnc #392605).
- Make it possible to override DNS information returned by DHCP.
* Tue May 13 2008 wstephenson@suse.de
- Fix enum syntax errors in installed headers.
- Fix 99%% CPU bug due to PolKitContext.
* Fri May  9 2008 tambet@suse.de
- Upgrade to the latest SVN:
  Update system settings suse plugin.
  Use PolicyKit to restrict changes to system connections.
  Add Keyfile system settings plugin.
  Allow multiple addresses for devices.
  Use libnl for all ip address and route manipulation.
  Don't require wireless-tools.
  Improve nm-online tool.
* Fri Apr 11 2008 tambet@suse.de
- Upgrade to the latest SVN:
  Automatically create a default connection for wired devices that are not
  configured in /etc/sysconfig.
  Implement ignoring devices that should be ignored by NM according to
  system configuration (Not used on suse yet).
  Internal VPN API rework.
  Lots of love to the libnm-glib.
  Fix DSL (pppoe) authentication.
  Make it build with gcc 4.3.
  Bug fixes.
* Mon Apr  7 2008 maw@suse.de
- The ppp package now installs various modules that NetworkManager
  uses in %%{_libdir}/pppd; adjust to that change.
* Fri Mar 14 2008 tambet@suse.de
- Fix a crasher bug triggered very frequently on waking up from suspend.
* Thu Mar 13 2008 tambet@suse.de
- Upgrade to the latest SVN:
  Implement support for multiple active devices.
  Implement support for DSL (pppoe) connection.
  Lots of public dbus API cleanup.
  Bug fixes.
* Wed Mar 12 2008 tambet@suse.de
- Work with updated HAL (bnc #369539).
* Mon Mar  3 2008 maw@suse.de
- Fix build on biarch systems.
* Fri Feb 29 2008 tambet@suse.de
- Upgrade to the latest SVN.
* Mon Feb 11 2008 coolo@suse.de
- fix pppd installation
* Tue Feb  5 2008 maw@suse.de
- Build with -fno-strict-aliasing.
* Mon Feb  4 2008 tambet@suse.de
- Upgrade to the latest SVN.
- Re-remove some files NM installs, they really aren't ready yet.
* Sat Jan 12 2008 schwab@suse.de
- Fix last change.
* Fri Jan 11 2008 aj@suse.de
- Install nm-tool and nm-online binaries and not
  the libtool wrappers (#353240).
- Add proper provides/obsoletes for dhcdbd.
* Fri Jan 11 2008 dmueller@suse.de
- fix file lists
- fix various specfile / packaging errors
* Wed Nov 28 2007 tambet@suse.de
- Upgrade to the unstable branch (0.7).
  - many changes and bugfixes
  - integrate all previous patches
  - switch to using dhcp-client instead of dhcdbd
  - gnome applet split off to own source
* Fri Sep 14 2007 tambet@suse.de
- Make sure gnome-keyring does not return empty result. (Novell #307910).
* Wed Aug 15 2007 tambet@suse.de
- Fix the hard-coded gnomesu path. (Novell #299518).
* Tue Aug  7 2007 tambet@suse.de
- Fix a crasher bug in nm-applet that was caused by a typo in a manually
  updated patch.
* Fri Aug  3 2007 sbrabec@suse.cz
- Updated gnome-patch-translation support.
* Fri Aug  3 2007 tambet@suse.de
- Update to the latest version from upstream:
    Add support for 2-phase authentication.
    Add support for rfkill switch.
- Add an editor for stored wireless networks.
- Fix the packaging bug where the log file was not owned by the package
    (Novell #280464).
- Fix the issue where NM doesn't honor YaST Static IP Settings
    (Novell #271757).
- Fix the packaging issue to not require gnome-panel (Novell #229291).
* Tue May 15 2007 pgajdos@suse.cz
- removed invalid PreReq: gtk2 >= {%%gtk_version} gnome-icon-theme
- added Requires: gtk2 >= {%%gtk_version}
- removed gnome-icon-theme from BuildRequires [#247450]
* Thu May 10 2007 tambet@suse.de
- Do not overwrite existing AP properties when merging the information from
  /etc/sysconfig/network/. Fixes the problem described in
  https://bugzilla.novell.com/show_bug.cgi?id=255765#c59
* Wed Mar  7 2007 jhargadon@suse.de
- fixed a problem with nm-resolv-conf-header-rml.patch (#249251)
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Tue Feb 13 2007 aj@suse.de
- Fix typo (it should be BuildRequires).
* Fri Feb  9 2007 sbrabec@suse.cz
- Removed remaining references to /opt/gnome (#243824).
- Build with libnotify.
- Spec file cleanup.
* Tue Jan 30 2007 sbrabec@suse.cz
- Changed GNOME prefix to /usr.
* Mon Nov 20 2006 tambet@suse.de
- Add a hack to fix translations (Novell #222329).
* Tue Nov 14 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation.
* Sun Nov 12 2006 thoenig@suse.de
- Add patch avahi-dbus-request-name-flags-fix-thoenig-01.patch:
  Fix flawed logic for flags passed to dbus_bus_request_name()
* Fri Nov 10 2006 tambet@suse.de
- Pull in latest CVS updates:
  - Fix a bunch of memory leaks and reference counting issues.
  (Novell #217027).
- Actually fix (Novell #212556).
- Implement disconnect wireless on exit (Novell #218848).
* Thu Nov  2 2006 tambet@suse.de
- Pull in latest CVS updates:
  - Suppress messages from the "SCAN" command.
  - Reduce the number of times the gnome applet wakes up.
  - Add LEAP authentication.
- Fix multiple problems with the fallback patch (Novell #212556):
  - Populate the key information from gconf for fallback keys.
  - Make sure the AP broadcast state isn't lost in case of fallback
  networks.
- Build fixes:
  - Merge all fallback related patches.
  - autoreconf before build to fix intltool issues.
  - Add some auto-detected Requires.
* Fri Oct 20 2006 tambet@suse.de
- Pull in latest CVS update: Don't kill nscd (#149613).
- Add a missing Requires to -devel package.
* Tue Oct 17 2006 tambet@suse.de
- Pull in latest CVS updates:
  - Don't loop infinitely if netmask is 0 (Gnome #352634)
  - Bump vpn timeout to 45s.
  - Backported async scanning patch backported from HEAD.
  - Make renaming a VPN entry work (Novell #193711).
  - Make sleep/wake distinguishable from enable/disable networking
  (Novell #199071).
  - Fix a packaging issue (Novell #212506).
- Add 'fallback' support (Novell #175172).
- Remove nm-dbus-api-fix-thoening-01.path as it's upstream now.
* Mon Sep 25 2006 thoenig@suse.de
- Do not "Require: NetworkManager-client" but "Recommend:
  NetworkManager-client" to avoid circular dependencies.
* Thu Aug 17 2006 rml@suse.de
- Pull in latest CVS updates:
  - Do not restart ypbind, as our ypbind now listens on DBUS
  - Less wpa_supplicant debug spew
  - Better key request logic
  - Fixes for big-endian machines in SHA-1 algorithm
  - Shutdown all VPN connections on logout (Novell #187714)
  - Fix memory leak
- Add libtool and iproute2 to BuildRequires
- Remove patch "nm-debug-wpa-less-rml.patch" as it is now upstream
* Wed Aug  9 2006 thoenig@suse.de
- Add patch: nm-dbus-api-fix-thoenig-01.patch
* Thu Jul 13 2006 rml@suse.de
- Update to NetworkManager 0.6.4
  - Lots of bugfixes
- Drop upstream patches
- Remove libnotify support and drop dependencies
* Wed Jun 28 2006 rml@suse.de
- Translation update
* Tue Jun 20 2006 rml@suse.de
- Put wpa_supplicant into Ad-Hoc mode for all Ad-Hoc networks, not
  just ones that NetworkManager itself creates (Novell bug #186806)
* Mon Jun 19 2006 rml@suse.de
- Fix automatic connection to WPA Enterprise networks (Novell bug
  [#175172])
* Fri Jun 16 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Mon Jun 12 2006 rml@suse.de
- nm-applet: Add nm-dialup-bugfix-183974.patch to fix bug where the
  applet's icon does not reflect dialup state (Novell bug #183974)
* Mon Jun 12 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Fri Jun  9 2006 rml@suse.de
- Add nm-roaming-bugfix-183320.patch to fix bug where a transient
  BSSID change was recorded as roaming (Novell bug #183338)
- nm-applet: Add nm-gconf-bugfix-183337.patch to fix bug where
  reading of booleans from Gconf always failed (Novell bug #183337)
- Add nm-bssid-bugfix-183343.patch to fix bug where NM would merge
  AP objects with zero BSSID values: AP objects should merge only
  when the BSSIDs are both valid and matching (Novell bug #183343)
- Add nm-dsl-bugfix-184031.patch to fix bug where NM was not
  enumerating DSL connections (Novell bug #184031)
* Fri Jun  2 2006 rml@suse.de
- Update translations (Novell bug #169096)
* Tue May 30 2006 rml@suse.de
- Fix crash in disposing of wireless objects before they are fully
  initialized (Novell bug #179525)
- Fix race on startup that prompted twice for wireless information
  (Novell bug #170587)
- nm-vpn-properties: Fix crash with NULL service names (Novell
  bug #179655)
- nm-vpn-properties: Fix option parsing (GNOME bug #33684)
- nm-vpn-properties: UI love (GNOME bug #336913)
- Update translations from GNOME CVS (Novell bug #169096)
- Rename NetworkManager-po-update.patch to nm-po-update.patch
* Mon May 29 2006 sbrabec@suse.cz
- Merged upstream translations from GNOME CVS (#169096#c37).
* Mon May 29 2006 sbrabec@suse.cz
- Use translation compendium gnome-patch-translation (#169096).
* Fri May 26 2006 rml@suse.de
- Make sure we require and correctly build with gcrypt support
  (Novell bug #179315)
* Thu May 25 2006 rml@suse.de
- For ndiswrapper, only use "AP_SCAN 2" if the network is not
  broadcasting (Novell bug #178210)
* Wed May 24 2006 rml@suse.de
- Do not fallback to link-local IP generation on infrastructure
  wireless networks, only Ad-Hoc  (Novell bug #178403)
- Set and use the current locale directory (Novell bug #169096)
- Bump version requirement on wpa_supplicant to 0.4.8-14 from
  0.4.8-9 (Novell bug #175892)
* Mon May 22 2006 rml@suse.de
- Fix ypbind/autofs behavior to never automatically start either,
  but only reload as needed (Novell bug #175935)
- nm-applet: Fix crash on icon-theme change if icons no longer
  exist (Novell bug #177426)
- Fix bug with weirdly-named network interfaces (GNOME bug #330832)
* Fri May 19 2006 ro@suse.de
- fix requirement. sysconfig in sles10 has release 13.3 currently
  (the version in sysconfig should have been fixed instead of
  requiring a release-number ...)
* Thu May 18 2006 rml@suse.de
- Use "AP_SCAN 2" for ipw2200 if the network is hidden (Novell
  bug #176575)
- nm-applet: Update Hungarian translation (Novell bug #158997)
- Bump package requirement on sysconfig to 0.50.9-14 or later
- Make sysconfig a PreReq, not a Requires (Novell bug #176993)
* Wed May 17 2006 rml@suse.de
- Add README.ypbind-autofs, describing the interaction between
  NetworkManager, ypbind, and autofs (Novell bug #175935)
- Automatically populate allowed MAC list from BSSIDs discovered
  via roaming (Novell bug #175172)
- Rediff nm-madwifi-strength-rml.patch
- nm-applet: Differentiate Ad-Hoc networks with unique icon
  (Novell bug #176589)
- Add patch nm-fix-adhoc-icon-rml.patch to workaround bad nm-adhoc
  icon
- Bump package requires on dhcdbd to version 1.12-19 or later
- Bump package requires on dhcp to version to 3.0.3-22 or later
* Tue May 16 2006 rml@suse.de
- Do not touch ypbind or autofs unless the sysconfig option
  dhcp:DHCLIENT_MODIFY_NIS_CONF is set to "yes" (Novell #175935)
* Mon May 15 2006 rml@suse.de
- Look for DHCLIENT_MODIFY_RESOLV_CONF in dhcp, not config (Novell
  bug #175688)
* Wed May 10 2006 rml@suse.de
- Fix double free causing crash on start with some ifcfg-wlan
  configurations (Novell bug #173442)
* Tue May  9 2006 rml@suse.de
- nm-applet: Save WPA EPA private key passhrase, if any, in the
  GNOME keyring and not in gconf (Novell bug #173823)
- Merge nm-online-header.patch into nm-0.6-branch.patch (fix is now
  upstream)
* Sun May  7 2006 jpr@suse.de
- Fix header include to fix build
* Tue May  2 2006 rml@suse.de
- Install nm-online utility (start of fix for Novell bug #169632)
- nm-applet: Don't try to convert blank network names to new-style
  gconf format
- Enable NM by default if installing for the first time (Novell
  bug #169964)
- Write out a YaST-friendly header in resolv.conf (Novell #171488)
- Fix WPA Passphrase entry on big-endian machines (GNOME #336991)
- Enforce sane umask on the daemon (Novell bug #173229)
- Respect dhcp:DHCLIENT_MODIFY_RESOLV_CONF, not
  config:MODIFY_RESOLV_CONF_DYNAMICALLY, when deciding whether to
  write out an updated /etc/resolv.conf (Novell bug #169858)
* Tue Apr 25 2006 rml@suse.de
- Fix "shared/restricted" key mode (Novell bug #168250)
* Fri Apr 21 2006 rml@suse.de
- Use "AP_SCAN 2" for airo_cs, too (Novell bug #168308)
* Thu Apr 20 2006 rml@suse.de
- For ipw2200, use "AP_SCAN 2" if the AP is hidden (166219)
- nm-vpn-properties: Don't let the user open more than one 'Configure
  VPN' window at a time, lest chaos ensue (Novell bug #165011)
- nm-applet: Don't bail out if the timestamp is not set
* Thu Apr 13 2006 rml@suse.de
- Install "nfs" dispatcher.d script to automatically restart NFS
  on interface up (Novell bug #156947)
* Wed Apr 12 2006 jg@suse.de
- Use wpa_supplicant 'wext' backend for ndiswrapper (Novell bug
  [#158892])
* Tue Apr 11 2006 rml@suse.de
- Use "AP_SCAN 2" for ndiswrapper (Novell bug #165315)
- VPN Configure: Don't crash when re-Adding a connection after
  closing window (Novell bug #153085)
* Mon Apr 10 2006 rml@suse.de
- VPN Configure: Don't disable 'Forward' button when entering
  dialog via 'Back' (Novell bug #164895)
* Thu Apr  6 2006 rml@suse.de
- Reflect active modem/ISDN connections in state.  Fixes bug where
  NM would report system as offline even if dial up connection were
  active (Novell bug #161611)
* Tue Apr  4 2006 rml@suse.de
- nm-applet: Remove 'Remove' option from right-click menu (undo
  Novell bug #155690)
* Wed Mar 29 2006 rml@suse.de
- Allow VPN modules to specify a per-route MSS value (bug #157988)
- Fix possible crash in strcmp (Novell bug #162104)
- Have NetworkManager require NetworkManager-client and have
  NetworkManager-gnome provide NetworkManager-client (bug #158326)
* Tue Mar 28 2006 rml@suse.de
- Don't let wpa_supplicant scan with the airo driver (bug #161389)
- Don't let wpa_supplicant scan when creating a new Ad-Hoc network,
  even if using the madwifi driver
- nm-applet: minor HIG-related UI tweaks
* Mon Mar 27 2006 rml@suse.de
- Revert ypbind restart behavior (Novell bug #159070)
- Bump wpa_supplicant requirement to version 0.4.8-9 (Bug #144268)
- Better handle capability detection and connection to EAP networks
- Use "AP_SCAN 2" even for non-broadcast networks (Bug #156970)
- Bump version to 0.6.2
* Sun Mar 26 2006 thoenig@suse.de
- Add unpackaged icons to %%files gnome
* Fri Mar 24 2006 rml@suse.de
- Fix VPN animation (Novell bug #153731)
- Fix minor glitch in wireless strength level icon
- nm-applet: Fix small memory leak in notification display
- libnm-glib.so belongs in -devel, too
- Merge patches nm-always-enable-wpa and nm-supplicant-timeout-rml
  into nm-wireless-driver-workarounds-rml.patch
- Require glib2 in NetworkManager-glib
* Fri Mar 24 2006 dmueller@suse.de
- libnm-util.so belongs in -devel
* Thu Mar 23 2006 rml@suse.de
- Let the applet reconnect to DBUS on restart (Novell bug #150042)
- Set DHCP timeout to 45s (Novell bugs #153243 and #159812)
- Do not override the gtk default invisible character
- Bump dbus-1 requirement to 0.60-22 or later
- Bump dhcdbd requirement to 1.12-9 or later
* Wed Mar 22 2006 rml@suse.de
- Properly handle "Dynamic WEP" (Novell bug #158589)
* Tue Mar 21 2006 rml@suse.de
- Respect and set per-device MTU value in sysconfig, if any (Novell
  bug #159354 and #157737)
* Tue Mar 21 2006 rml@suse.de
- Fix crash in parsing hex keys from sysconfig (Novell #159394)
* Fri Mar 17 2006 rml@suse.de
- Do not restart ypbind on NIS configuration change, just ask it
  to reload its configuration (Novell bug #159070)
- No longer start dhcdbd, but rely on sysconfig to start it before
  it starts NetworkManager, fixing a race (Novell bug #159125)
- Require sysconfig 0.50.7 or later
* Thu Mar 16 2006 rml@suse.de
- Do not run gtk-update-icon-cache in post (Novell bug #158381)
- Rename patch 'nm-configure-modem-item-rml.patch' to
  'nm-configure-networking-rml.patch'
- Add patch 'nm-0.6-branch.patch' to fix behavior in reading static
  wireless configurations from sysconfig
- Don't down devices on suspend (Novell bug #142960 and #156509)
- Merge 'nm-bug-fix-157048-rml.patch' into 'nm-0.6-branch.patch'
* Mon Mar 13 2006 rml@suse.de
- Add 'Configure Networking' option that invokes YaST
* Mon Mar 13 2006 rml@suse.de
- nm-applet: Fix duplicate widgets in 'Add VPN' (Novell
  bug #157048)
- Actually apply 'nm-debug-wpa-less-rml.patch'
* Mon Mar 13 2006 rml@suse.de
- Update to 0.6.1
- Have the dispatcher daemon survive DBUS restarts
- Add patch 'nm-debug-wpa-less-rml.patch'
* Fri Mar 10 2006 rml@suse.de
- Don't let wpa_supplicant log keys, either (Bug #156977)
- Orinoco tweak (Bug #144268)
- nm-applet: add checkbox for un-hiding password entry
* Fri Mar 10 2006 rml@suse.de
- Update to 0.6.0cvs20060310
- Fix WPA Enterprise SEGV on successfull connect (Bug #156973)
- Do not log WPA Enterprise password in clear text (Bug #156977)
* Thu Mar  9 2006 rml@suse.de
- Update to 0.6.0cvs20060309
- Parse sysconfig encryption settings, too
* Wed Mar  8 2006 rml@suse.de
- Update to 0.6.0cvs20060308
- nm-applet: Hide password keystrokes (Novell beta customer)
- Trust wireless networks in sysconfig
* Tue Mar  7 2006 rml@suse.de
- Update to 0.6.0cvs20060307
- nm-applet: Add 'Remove' option to the applet (Novell bug #155690)
* Mon Mar  6 2006 rml@suse.de
- Have NetworkManager.pc provide the NetworkManager include
  directory in CFLAGS.
- Undo prism54 workarounds
- Specifically match against "airo" for the airo driver workaround
- Better logging for dhcdbd events
* Mon Mar  6 2006 rml@suse.de
- Update to 0.6.0cvs20060306
- Workarounds for prism54 wireless driver (Novell bug #148210
  and #144938)
- Workaround for airo wireless driver
- Improved handling of activation cancellation (Novell bug #150787)
* Fri Mar  3 2006 rml@suse.de
- Update to 0.6.0 (just a version bump)
* Fri Mar  3 2006 rml@suse.de
- Update to 0.5.1cvs20060303
- nm-applet and nm-tool: Display per-device speed and per-network
  maximum bitrate (Novell bug #154451)
- Fixes for orinoco_cs driver (Novell bug #144268)
- Fixes for ndiswrapper driver (Novell bug #153536)
- Do not scan-spam the driver on startup
- Replace nm-madwifi-wpa-driver-rml.patch with
  nm-wireless-driver-workarounds-rml.patch
- Misc. cleanup
* Thu Mar  2 2006 rml@suse.de
- Update to 0.5.1cvs20060302
- nm-applet: move autostart file to proper location
- Fix crash on connecting to VPN while already connecting (Novell
  bug #152502)
- Workaround for ndiswrapper wireless problems (Novell bug #153536)
* Tue Feb 28 2006 rml@suse.de
- Update to 0.5.1cvs20060228
- Respect MODIFY_RESOLV_CONF_DYNAMICALLY defined in the file
  /etc/sysconfig/network/config and do not update resolv.conf,
  even if DHCP supplies name servers, if this variable is set to
  "yes" (Novell bug #147703)
- Log wpa_supplicant's responses to /var/log/NetworkManager, too
- Don't prune the wireless network scan list too aggressively
- Misc. WPA Enterprise clean up
* Mon Feb 27 2006 rml@suse.de
- Create pid files in both the NetworkManager and
  NetworkManagerDispatcher daemons
- nm-applet: Remove all gconf keys on VPN removal (Novell #153628)
- nm-applet: Let <ENTER> submit passphrase dialog (Novell #153738)
* Mon Feb 27 2006 rml@suse.de
- Own /opt/gnome/share/NetworkManager/
* Mon Feb 27 2006 rml@suse.de
- Update to 0.5.1cvs20060227
- WPA-Enterprise support! (Bug #134238)
- Remove patches nm-dbus-reconnect-thoenig-03.patch and
  nm-transparent-trayicon.patch, both are now upstream
- Log backtrace on crash
- Updated libnotify notification
* Wed Feb 22 2006 thoenig@suse.de
- Update patch nm-dbus-reconnect-thoenig-03.patch: Take care that
  dhcdbd will get back after we've reconnected to the system bus
  (#150042)
* Wed Feb 22 2006 danw@suse.de
- Add nm-transparent-trayicon.patch to make the tray icon
  pretty under KDE. #135448
* Wed Feb 22 2006 thoenig@suse.de
- Add patch to make NM reconnect to the D-BUS system bus if it
  breaks away (#150042)
* Tue Feb 21 2006 rml@suse.de
- Update to 0.5.1cvs20060221
- Do not stomp on others using the default shared dbus connection
  (Fixes GNOME #326572)
- Add libnotify notifications to nm-applet
* Sun Feb 19 2006 aj@suse.de
- Reduce BuildRequires.
* Wed Feb 15 2006 rml@suse.de
- Update to 0.5.1cvs20060215
- Fix VPN GUI dialog when successively editing entries of two
  or more different VPN types (Novell bug #150854)
- Improve debugging output
* Tue Feb 14 2006 rml@suse.de
- Update to 0.5.1cvs20060214
- Fix connecting non-broadcast encrypted networks (blocker #150784)
* Mon Feb 13 2006 rml@suse.de
- Update to 0.5.1cvs20060213
- VPN fixes for Novell VPN
- Fix small memory leak
* Tue Feb  7 2006 rml@suse.de
- Always use "AP_SCAN 1" with wpa_supplicant -- madwifi needs it
* Tue Feb  7 2006 rml@suse.de
- Update to 0.5.1cvs20060207
- Fix off-by-one error that broke some WEP connections (#148646)
* Mon Feb  6 2006 rml@suse.de
- Add back nm-supplicant-timeout-rml.patch when new, larger
  timeout value
* Mon Feb  6 2006 rml@suse.de
- Update to 0.5.1cvs20060206
- Better handling of non-broadcast networks
- Merge half of nm-madwifi-wpa-driver-rml.patch upstream
- Remove nm-supplicant-timeout-rml.patch, merged upstream
* Fri Feb  3 2006 rml@suse.de
- Update to 0.5.1cvs20060203
- Do not log encryption information (per bug #147748)
- Fix memory leak in SUSE backend
* Thu Feb  2 2006 rml@suse.de
- Update to 0.5.1cvs20060202
- Better broadcast networks (better fix for #144622)
- Own /var/run/NetworkManager
- Remove 'ntp' and 'SuSEfirewall' scripts and move to requisite
  packages
- Update API for novellvpn
* Wed Feb  1 2006 rml@suse.de
- Update to 0.5.1cvs20060201
- Remove '--sm-disable' from autostart file via sed
- Add nm-tool(1) man page
- Add nm-madwifi-fixes-rml.patch (Fixes critical bug #144622)
* Tue Jan 31 2006 rml@suse.de
- Update to 0.5.1cvs20060131
- Set "set_ssid " in wpa_supplicant for non-broadcasting networks
- More #138404 fixes
* Mon Jan 30 2006 rml@suse.de
- Update to 0.5.1cvs20060130
- Fixes #144624, half of #134238
- Initial #138404 fix
* Fri Jan 27 2006 rml@suse.de
- Update to 0.5.1cvs20060127
- Fixes #144324
* Thu Jan 26 2006 rml@suse.de
- Update to 0.5.1cvs20060126
- Move all non-GNOME bits out of /opt/gnome
* Wed Jan 25 2006 rml@suse.de
- Update to 0.5.1cvs20060125
- Remove temporary patch nm-dhcp-hostname-byte-array-thoenig-01,
  merged upstream
- Add nm-fix-madwifi-strength-rml.patch, fixing strength output of
  Atheros devices
- Update BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 thoenig@suse.de
- temporary patch nm-dhcp-hostname-byte-array-thoenig-01.patch to
  solve #145273
* Mon Jan 23 2006 rml@suse.de
- Require libgnomesu in NetworkManager-gnome
- Add ISDN Configuration menu item, too (Fixes #140756-ng)
- Respect DHCLIENT_SET_HOSTNAME (Fixes #144324)
* Mon Jan 23 2006 rml@suse.de
- Update to 0.5.1cvs20060123
- Move daemons to /usr/sbin from /usr/bin (Fixes #144033)
- Spec file tweaks
* Thu Jan 19 2006 rml@suse.de
- Update to 0.5.1cvs20060119
- Respect NM_CONTROLLED flag in sysconfig
* Wed Jan 18 2006 rml@suse.de
- Update to 0.5.1cvs20060118
- Fixes #143725
- Add nm-never-restart-nm-applet-rml-1.patch
- Remove no-longer-needed insserv calls
- Move ldconfig run from preun to postun
- Misc. spec file cleanup
* Tue Jan 17 2006 rml@suse.de
- Update to 0.5.1cvs20060117
- Fixes #143496
* Mon Jan 16 2006 rml@suse.de
- Update to 0.5.1cvs20060116
- Fixes #135595
- C++-sanitizes headers for thoenig
* Fri Jan 13 2006 rml@suse.de
- Update to 0.5.1cvs20060113
* Thu Jan 12 2006 rml@suse.de
- Fix Novell #142773.
* Thu Jan 12 2006 rml@suse.de
- Update to 0.5.1cvs20060112
- Adds WPA-1 and WPA-2 support (fixes bug #134238)
* Mon Jan  9 2006 rml@suse.de
- Update to 0.5.1cvs20060107
* Mon Jan  9 2006 ro@suse.de
- remove ExcludeArch
* Fri Jan  6 2006 rml@suse.de
- Update to 0.5.1cvs20060106
- Fix #140733 and 140756, maybe fix #139300
* Wed Jan  4 2006 rml@suse.de
- Update to 0.5.1cvs20060104
- Redo kernel header patch
* Tue Dec 20 2005 ro@suse.de
- fix build by avoiding some more kernel headers
* Mon Dec 19 2005 rml@suse.de
- Update nm-applet.desktop
* Mon Dec 19 2005 rml@suse.de
- Update Requires
* Fri Dec 16 2005 rml@suse.de
- Add SuSEfirewall script to dispatcher.d to recycle firewall
  on interface change (per aj).
* Wed Dec 14 2005 rml@suse.de
- Write out header on resolv.conf (fixes #137762)
- Force nm-applet.desktop permissions
* Mon Dec 12 2005 rml@suse.de
- Update to 0.5.1cvs20051212 (fixes #134369)
- Add libnm-util packages
* Fri Dec  9 2005 rml@suse.de
- Update to 0.5.1cvs20051209
- Add Tango icons
* Thu Dec  8 2005 rml@suse.de
- Update to 0.5.1cvs20051208
- Add networkmanager-dispatcher initscript and start it
* Wed Dec  7 2005 rml@suse.de
- Update to 0.5.1cvs20051207
- Fixes b.n.c bug #94552
- Add NetworkManagerVPN.h file to devel subpackage
* Thu Dec  1 2005 rml@suse.de
- Update to 0.5.1cvs20051201.  Fixes b.n.o #134178.
* Tue Nov 22 2005 rodrigo@suse.de
- Added autostart file for nm-applet.
* Mon Nov 14 2005 rml@suse.de
- Update to CVS snapshot 20051114
* Mon Nov  7 2005 thoenig@suse.de
- removed 'Conflicts: dhcpcd'
* Fri Nov  4 2005 rml@suse.de
- Update to CVS snapshot 20051104
- gnome-keyring 0.4.4 is fine
* Wed Nov  2 2005 rml@suse.de
- Update to CVS snapshot 20051102 (fixes Novell bug #130041).
- Add patch nm-logarithmic-quality.patch
- Require libnl
- BuildRequire libnl, libnl-devel
* Fri Oct 28 2005 rml@suse.de
- Move gnome-keyring requirement to -gnome subpackage.
* Thu Oct 27 2005 rml@suse.de
- Require gnome-keyring.
* Tue Oct 25 2005 thoenig@suse.de
- fixed duplicated '-p $RPM_BUILD_ROOT%%{_sbindir}' in spec file
* Tue Oct 25 2005 thoenig@suse.de
- added symlink
  /usr/sbin/rcnetworkmanager -> /etc/init.d/networkmanager
* Wed Oct 19 2005 rml@suse.de
- Version 0.5.1
- Update to CVS snapshot 20051019-
* Thu Oct  6 2005 rml@suse.de
- Update to CVS snapshot 20051004.
* Thu Sep 29 2005 thoenig@suse.de
- nm-configure-modems-item-rml-1.patch: added absolute path for
  invocation of gnomesu
* Tue Sep  6 2005 rml@suse.de
- Fix bug #114803, crasher.
* Mon Aug 22 2005 gekker@suse.de
- Update to version 0.4cvs20050805 which fixes bug #105355.
* Fri Aug  5 2005 gekker@suse.de
- Update to version 0.4cvs20050805
- Fixes modem support
* Mon Jul 25 2005 kasievers@suse.de
- New version 0.4cvs20050725
* Wed Jul 20 2005 jpr@suse.de
- Build against dbus 0.35
* Thu Jun 30 2005 gekker@suse.de
- Upate to version 0.4cvs20050630
- Update patch for connection dialog
- Remove patched NetworkManager.conf source
* Wed Jun 29 2005 gekker@suse.de
- Fix DHCDBD_BINARY_PATH
* Tue Jun 28 2005 gekker@suse.de
- update to 0.4cvs20050628
- add suspend/resume support
- add powersave to nfb
- change Requires for rml
* Fri Jun 24 2005 ro@suse.de
- update to 0.4cvs20050617
* Thu Jun 23 2005 ro@suse.de
- search for dhcdbd also in /usr/sbin
* Mon Jun 20 2005 hare@suse.de
- Initial checkin for autobuild.
